@@ -1,21 +1,21 @@
 import os, json
 class Database:
-  def __init__(self, path = 'data.db'):
+  def __init__(self, path: str = 'data.db'):
     self.path = path
     if not os.path.exists(path): 
       with open(path, 'x') as f: f.close()
   def put(self, data):
     with open(self.path, 'a') as f: f.write(json.dumps(data, separators=(',', ':')) + '\n'); f.close()
-  def find(self, cb):
+  def find(self, cb: function):
     with open(self.path, 'r') as f:
-      r = ''
+      r = None
       for l in f:
         j = json.loads(l)
         try:
           if cb(j): r = j; break
-        except: None
+        except: pass
       f.close(); return r
-  def remove(self, cb):
+  def remove(self, cb: function):
     with open(self.path, 'r') as r, open(self.path + '.bak', 'w') as w:
       o = True
       for l in r:
